@@ -100,6 +100,11 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         default='',
         help_text="Text qui apparait sur un block Social Share"
     )
+    social_links_text = RichTextField(
+        blank=True,
+        default='',
+        help_text="Text qui apparait sur un block Social Links"
+    )
     newsletter = models.ForeignKey(
         Form,
         null=True,
@@ -152,6 +157,7 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
 
     socials_panels = [
         FieldPanel('social_share_text'),
+        FieldPanel('social_links_text'),
         FieldPanel('facebook'),
         FieldPanel('instagram'),
         FieldPanel('linkedin'),
